% Incomplete !!

function [I_s,trueCells,vertex,c,w] = I_s_variance(masks,division,sq_size,vertex)

% Calculates the segregation index, I_s,
% using the method of variance.


% Input:

% masks: 2-d uint8 array
% (created by e.g. rgbTrisect.m) with values:
% 1 = red, 2 = glass, 0 = background

% division: string
% It defines the method used for the division in cells.
% It can be one of the following:
% 'simple','specific','random','similar','optimum'

% sq_size: integer number
% It is the length of each square cell.
% It must be less than the smallest of the first two dimensions of masks.
% If not given, an automatic value is chosen.

% vertex: integer 1 x 2 matrix
% It is the top-left vertex of a cell in the cell grid.


% Output:

% I_s: double 1 x 2 matrix, values between 0 and 1
% It is the segregation index. The values returned are:
% [I_s_red I_s_glass]

% trueCells: number of non-background cells, real
% Each cell is weighed by its number of non-background pixels
% to give a contribution to trueCells between 0 and 1.

% vertex: the top-left of the first full cell


% Preliminary calculations

[height,width] = size(masks);

if nargin < 3 || sq_size > min(height,width)
    sq_size = 100;
end

if sq_size > min(height,width)
    sq_size = floor(min(height,width)/2);
end

% 1st step: Choose division method

if nargin < 2 || isequal(division,'simple')
    
    % Divides starting from the top left corner.
    cells = simple_division(masks,sq_size);
    vertex = [1,1];
    
elseif isequal(division,'specific')
    
    % Divides starting from a specific point (vertex),
    % which is the top left point of a cell.
    cells = specific_division(masks,sq_size,vertex);
    vertex = find_vertex(vertex,sq_size);
    
elseif isequal(division,'random')
    
    % Divides starting from a random point in the image.
    [cells,vertex] = random_division(masks,sq_size);
    
elseif isequal(division,'similar')
    
    % Minimizes the area difference among cells
    % by setting the center of the image to be the center of a cell.
    [cells,vertex] = similar_division(masks,sq_size);

elseif isequal(division,'optimum')
    
    % Finds the optimum vertex, by maximizing the variance
    % between background and non-background
    [cells,vertex] = optimum_division(masks,sq_size);
    
else
    
    msg = 'The variable ''division'' was not correctly defined';
    error(msg)
    
end

% 2nd step: Calculate concentration in each cell

noOfCells = numel(cells);
cells = reshape(cells,[1 noOfCells]);
N = 0;
c_r = zeros(1,noOfCells); % red concentration vector
c_g = zeros(1,noOfCells); % glass concentration vector
w = zeros(1,noOfCells); % weight vector (to account for
% the different size of each non-background cell

for k = 1:noOfCells
    % For each cell, first check if it totally background:
    %total_area = numel(cells{k})/size(cells{k},3);
    %total_area = numel(cells{k});
    %back_area = sum(sum(cells{k}==0));
    
    if sum(sum(cells{k})) > 0
    %if back_area < total_area
        % If the cell contains non-background:
        
        N = N + 1;
        
        red = cells{k}==1;
        glass = cells{k}==2;
        red_area = sum(sum(red));
        glass_area = sum(sum(glass));
        
        w(N) = (red_area + glass_area)/(sq_size^2);
        c_r(N) = red_area/(red_area + glass_area);
        c_g(N) = glass_area/(red_area + glass_area);

    end
    
end

% 3rd step: Calculate segregation index

c_r = c_r(1:N)';
c_g = c_g(1:N)';
w = w(1:N)';
trueCells = sum(w);
c = [c_r c_g];

c_avg = sum(w.*c)/trueCells;

I_s = sqrt((sum(w.*(c-c_avg).^2))/(trueCells - 1));

%I_s = sqrt((sum(w.*(c-mean(c)).^2))/(trueCells - 1));

%I_s = var(c,w);

end

function cells = simple_division(masks,sq_size)

% Divides starting from the top left corner.

[height,width] = size(masks);

NoOfCellRows = floor(height./sq_size);
NoOfCellCols = floor(width./sq_size);
rowDist = sq_size*ones(1,NoOfCellRows);
colDist = sq_size*ones(1,NoOfCellCols);

if sum(rowDist) < height
    rowDist = [rowDist, height - sum(rowDist)];
end

if sum(colDist) < width
    colDist = [colDist, width - sum(colDist)];
end

cells = mat2cell(masks,rowDist,colDist);

end

function cells = specific_division(masks,sq_size,vertex)

% Divides starting from a specific point (vertex),
% which is the top left point of a cell.

% vertex: 1 x 2 integer matrix

[height,width] = size(masks);
x0 = vertex(1);
y0 = vertex(2);

cells4 = mat2cell(masks,[x0-1 height-x0+1],[y0-1 width-y0+1]);
cells1 = {};
cells2 = {};

if ~isempty(cells4{1,1})
    A = rot90(cells4{1,1},2);
    cells1 = simple_division(A,sq_size);
    cells1 = rot90(cells1,-2);
end

if ~isempty(cells4{1,2})
    A = flipud(cells4{1,2});
    cells_temp1 = simple_division(A,sq_size);
    cells_temp1 = flipud(cells_temp1);
    cells1 = [cells1, cells_temp1];
end
    
if ~isempty(cells4{2,1})
    A = fliplr(cells4{2,1});
    cells2 = simple_division(A,sq_size);
    cells2 = fliplr(cells2);
end

A = cells4{2,2};
cells_temp2 = simple_division(A,sq_size);
cells2 = [cells2, cells_temp2];

cells = [cells1; cells2];

end

function [cells,vertex] = random_division(masks,sq_size)

% Divides starting from a random point in the top left sq_size square.

vertex = [0 0];
for i = 1:2
    vertex(i) = randi(sq_size);
end

cells = specific_division(masks,sq_size,vertex);
vertex = find_vertex(vertex,sq_size);

end

function [cells,vertex] = similar_division(masks,sq_size)

% Minimizes the area difference among cells
% by setting the center of the image to be the center of a cell.

[height,width] = size(masks);

img_center = [height width]/2;
vertex = floor(img_center - sq_size/2*ones(1,2));

cells = specific_division(masks,sq_size,vertex);
vertex = find_vertex(vertex,sq_size);

end


function [cells,vertex] = optimum_division(masks,sq_size)

% Finds the optimum(?) vertex, by maximizing the variance
% between background and non-background

max_variance = 0;

for i = 1:sq_size
    for j = 1:sq_size
        
        cells_ij = specific_division(masks,sq_size,[i j]);
        noOfCells = numel(cells_ij);
        cells_ij = reshape(cells_ij,[1 noOfCells]);
        
        areas_ij = zeros([1 noOfCells]);
        
        for k = 1:noOfCells
            % For each cell, extract the background:
            back = cells_ij{k}==0;
            % Save its area:
            areas_ij(k) = sum(sum(back));
        end
        
        % Reassign vertex if variance is bigger:
        if var(areas_ij) > max_variance
            max_variance = var(areas_ij);
            vertex = [i j];
        end
        
    end
end

cells = specific_division(masks,sq_size,vertex);

end

function vertex_top_left = find_vertex(vertex,sq_size)

vertex_top_left = mod(vertex,sq_size);

for i = 1:2
    if vertex_top_left(i) == 0
        vertex_top_left(i) = sq_size;
    end
end

end