% incomplete !!!

function [M,cell_size,vertex,I] = M_variance3D(MasksArray,ball_diameter,...
    cell_to_diameter_ratio,mode,track)

% Calculates the mixing index using the variance method, calling the
% function:

% [I_s,trueCells,vertex,c,w] = I_s_variance(masks,division,sq_size,vertex)

% for an array of masks.

% Input

% MasksArray: uint8 H x W x F matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)

% ball_diameter: the diameter of the particles (in pixels)

% cell_to_diameter_ratio: the cell size is determined by this ratio,
% rounded to the closest integer if necessary

% mode: character, indicates the grid position, possible values:
    % 'simple': the top left pixel of each frame is the top left pixel of a
        % cell
    % 'random': places the grid randomly
    % 'center': places the center of a cell in the center of each frame
    % 'minimum': calculates the minimum mixing index over all possible grid
        % positions
    % 'maximum': calculates the maximum mixing index over all possible grid
        % positions
% default value: 'center'
if nargin < 4
    mode = 'center';
end

% track: logical, if true the current frame processed is shown.
% Default value: false
if nargin < 5
    track = 0;
end

% Output

% M: double F x 1 matrix, contains the values of the mixing index for each
% frame

% cell_size: integer, the calculated cell size (in pixels)

% vertex: integer F x 2 matrix
% vertex(:,fr) is the top-left pixel of the first full cell of frame fr

% I: double F x 1 matrix, contains the values of the segregation index for
% each frame

%% Preliminary calculations

F = size(MasksArray,3);
if track
    strF = num2str(F);
end

cell_size = round(ball_diameter*cell_to_diameter_ratio);

M = zeros(F,1);
I = zeros(F,1);
vertex = zeros(F,2);

c_avg = find_c_avg(MasksArray);

if isequal(mode,'random')
    verrand = [0 0];
    for i = 1:2
        verrand(i) = randi(cell_size);
    end
end

for fr = 1:F
    
    if track
        strframe = num2str(fr);
        disp(['Current frame: ',strframe,'/',strF]);
    end
    
    masks = MasksArray(:,:,fr);
    % M(fr) = M_contact_noback(masks,ball_diameter);
    
    %% Calculate segregation index
    
    % [I_s,trueCells,vertex,c,w] = I_s_variance(masks,division,sq_size,vertex)
    
    if isequal(mode,'simple')
        
        [I_s,~,ver] = I_s_variance(masks,'simple',cell_size);
        
    elseif isequal(mode,'random')
        
        [I_s,~,ver] = I_s_variance(masks,'specific',cell_size,verrand);
        
    elseif isequal(mode,'center')
        
        [I_s,~,ver] = I_s_variance(masks,'similar',cell_size);
        
    elseif isequal(mode,'minimum') || isequal(mode,'maximum')
        
        I_s_grid = zeros(cell_size);
        
       for ii = 1:cell_size
           for jj = 1:cell_size
               
               I_s = I_s_variance(masks,'specific',cell_size,[ii jj]);
               I_s_grid(ii,jj) = I_s(1);
               
           end
       end

       if isequal(mode,'minimum')
           [I_s,idx] = max(I_s_grid(:));
       else % mode: maximum
           [I_s,idx] = min(I_s_grid(:));
       end

       [ver_i,ver_j] = ind2sub(cell_size*[1 1],idx);
       ver = [ver_i ver_j];
       
    else
        error('Argument ''mode'' not valid.')
    end
    
    I(fr) = I_s(1);
    vertex(fr,:) = ver;
    
    %% Calculate mixing index
    
    color_area = sum(sum(masks~=0));
    N = color_area/(cell_size^2);
    c = c_avg(fr);
    I_max = sqrt(N/(N-1)*c*(1-c));
    
    M(fr) = 1 - I(fr)/I_max;
    
end