function RGBVid = Pvid2RGB(Pvid)

% Converts a video Pvid into an RGB video, using the value-to-color
% correspondence in Pvid.

% Theodoros-Nestor Papapetrou
% Last edited: 08 Oct 2020

%% Input

% Pvid: uint8 H x W x F matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)
% P represents a video of the rotating drum with red and white particles

%% Output

% RGBVid: H x W x 3 x F uint8 array, the color image of P

%% Initialization

Psize = size(Pvid);
H = Psize(1);
W = Psize(2);

% Check if Pvid corresponds to a video (F > 1) or a single image (F = 1)
if numel(Psize) == 2 % single image
    F = 1;
else % video
    F = Psize(3);
end

RGBVid = zeros([H,W,3,F],'uint8');

%% Conversion of each frame

for fr = 1:F
    
    P = Pvid(:,:,fr);

    % Build green and blue channels
    BG = zeros([H,W],'uint8');
    BG(P == 2) = 255;

    % Build red channel
    R = BG;
    R(P == 1) = 255;

    % Build RGBVid frame
    RGBVid(:,:,:,fr) = cat(3,R,BG,BG);
    
end
