function [Xbot, Ybot] = bottomSurface(P)

% Extracts the coordinates of the bottom surface of a rotating drum. The
% output coordinates are given as x and y coordinates (not image
% columns / rows). Any background rows and columns are not taken into
% account.

% Theodoros-Nestor Papapetrou
% Last edited: 05 Oct 2020

%% Input

% P: uint8 H x W matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)
% P represents an image of the rotating drum with red and white particles

%% Output

% Xbot: array with the x-coordinates of the points of the bottom surface
% (in pixels)

% Ybot: array with the y-coordinates of the points of the bottom surface
% (in pixels)

%% Calculations

P = remove_0_cols_rows(P);
[H,W] = size(P);

Xbot = imcols2x([1:W]);
rows = zeros(1,W);
for jj = 1:W
    rows(jj) = find(P(:,jj),1,'last');
end
Ybot = imrows2y(rows,H);