function [xd,yd,xu,yu] = circleIntersections(x0,y0,x1,y1,r0,r1)

% Calculates the intersection points of two circles with the smallest
% y-coordinate.
% The calculation is done according to the section "Intersection of two
% circles" of:
% http://paulbourke.net/geometry/circlesphere/ (access: 15 Sep 2020)
% The circles are considered to have exactly two intersection points.

%% Input

% x0: x-coordinate of the center of the 1st circle
% y0: y-coordinate of the center of the 1st circle
% x1: x-coordinate of the center of the 2nd circle
% y1: y-coordinate of the center of the 2nd circle
% r0: radius of the 1st circle
% r1: radius of the 2nd circle

%% Output

% xd: x-coordinate of the lowest intersection point
% yd: y-coordinate of the lowest intersection point
% xu: x-coordinate of the highest intersection point
% yu: y-coordinate of the highest intersection point

%% Calculation

d = sqrt((x1-x0)^2 + (y1-y0)^2); % distance between the centers,
                                 % considered bigger than abs(r0-r1) and
                                 % smaller than r0+r1
a = (r0^2 - r1^2 + d^2)/(2*d);
h = sqrt(r0^2 - a^2);
x2 = x0 + a*(x1 - x0)/d;
y2 = y0 + a*(y1 - y0)/d;
dx = h*(y1 - y0)/d;
dy = h*(x1 - x0)/d;

if dy > 0
    yd = y2 - dy;
    xd = x2 + dx;
    yu = y2 + dy;
    xu = x2 - dx;
else % dy <= 0
    yd = y2 + dy;
    xd = x2 - dx;
    yu = y2 - dy;
    xu = x2 + dx;
end