function c_avg = find_c_avg(P_sequence)

% Calculates the average red concentration for each image in a sequence,
% using the discretized form of Eq. 6.

% Theodoros-Nestor Papapetrou
% Last edited: 02 Oct 2020

%% Input

% P_sequence: uint8 H x W x F matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)
% Each page of P_sequence represents an image of the rotating drum with red
% and white particles

%% Output

% c_avg: double F x 1 array, containing the average red concentration of
% each frame

%% Calculation

F = size(P_sequence,3); % no of frames
c_avg = zeros(F,1);

for fr = 1:F
    P = P_sequence(:,:,fr);
    red_area = sum(sum(P==1));
    white_area = sum(sum(P==2));
    c_avg(fr) = red_area/(red_area + white_area);
end