function C = find_noOfContacts(P,direction)

% Counts the number of contacts, C, between red and white pixels in an
% image along the specified direction (row, column, or both). If both
% directions are selected, this is the value of the original contact method
% for a single image.

% Theodoros-Nestor Papapetrou
% Last edited: 06 Oct 2020

%% Input

% P: uint8 H x W matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)
% P represents an image of the rotating drum with red and white particles

% direction: string, indicates the direction along which contacts are
% counted. It can have the values:
    % 'row': calculates C along all the rows of masks
    % 'col': calculates C along all the columns of masks
    % 'both': calculates C along both rows and columns of masks
    
%% Output

% C: the total number of contacts (integer scalar)

%% Check of direction

if isequal(direction,'row')
    direction = [true false];
elseif isequal(direction,'col')
    direction = [false true];
elseif isequal(direction,'both')
    direction = [true true];
else
    msg = 'The variable ''direction'' was not correctly defined.';
    error(msg)
end

%[height,width] = size(masks);

C = 0;

%% Counting of horizontal contacts

if direction(1)
    %for i = 1:height
    %    for j = 1:width - 1
    %        if masks(i,j) + masks(i,j+1) == 3
    %            C = C + 1;
    %        end
    %    end
    %end
    
    Left = P(:,1:end-1);
    Right = P(:,2:end);
    SumHor = Left + Right;
    C = nnz(SumHor == 3);
    
end

%% Counting of vertical contacts

if direction(2)
    %for j = 1:width
    %    for i = 1:height - 1
    %        if masks(i,j) + masks(i+1,j) == 3
    %            C = C + 1;
    %        end
    %    end
    %end
    
    Up = P(1:end-1,:);
    Down = P(2:end,:);
    SumVert = Up + Down;
    C = C + nnz(SumVert == 3);
    
end