function y = imrows2y(rows,height)

% Converts the row numbers of an image to y coordinates.
% The x and y axes have the usual orientation and the origin is at the low
% left corner of the image. The resulting x and y are at the center of the
% corresponding pixels.
% For example, the pixel at the left bottom of the matrix with column
% number 1 and row number H (the height of the matrix), has coordinates
% x=0.5, y=0.5
% This is the inverse function of y2imrows.

% Theodoros-Nestor Papapetrou
% Last edited: 05 Oct 2020

%% Input

% rows: array containing row numbers of an image matrix

% height: the number of rows of the image (integer scalar)

%% Output

% y: array (same size as rows) with the corresponding y-coordinates of the
% rows, with respect to the xy-system

%% Calculation

if ~isempty(rows)
    y = height + 0.5 - rows;
else
    error('Empty input')
end