function A = redArea(r,h,x)

% Calculates the area of the red (left) region of the drum for a fully
% segregated state (Fig. 5b), using Eq. 15

% Theodoros-Nestor Papapetrou
% Last edited: 08 Oct 2020

%% Input

% r: drum radius (double scalar)
% h: filling height (h-tilde in the paper) (double scalar)
% x: horizontal coordinate of the vertical separating line between red and
% white (l-tilde in the paper) (double scalar)

% All input variables must be given in the same length_units.

%% Output

% A: area of the red (left) region, in (length_units)^2 (double scalar)

%% Calculations

h_ = r - sqrt(x*(2*r-x)); % h*-tilde in the paper
l_ = r - sqrt(h*(2*r-h)); % l*-tilde in the paper
theta = pi - acos(x/r-1) + asin(h/r-1);

A = (x*(h-h_) + h*(x-l_) + r*(h_-h+l_-x) + r^2*theta)/2; % Eq. 15