function viewMultithreshLevels(img,noOfThresholds)

% Shows the levels of a grayscale image segmented with the multithresh
% function. Used to visually determine the appropriate frame, number of
% thresholds and level needed for the creation of the circular mask (in
% parameters_1.m). For a given image, noOfThresholds should be manually
% increased until a value such that there exists a level (masked image)
% that includes the entire drum circle, but no pixels outside it.

% Theodoros-Nestor Papapetrou
% Last edited: 03 Feb 2023

%% Input

% img: H x W unit8 matrix, grayscale image
% noOfThresholds: positive integer, number of automatically calculated
% thresholds

%% Calculations

[H,W,~] = size(img);
noOfLevels = noOfThresholds + 1;
thresh = multithresh(img,noOfThresholds);
quantImg = imquantize(img,thresh);
mask = zeros([H,W,noOfLevels],'logical');
imgMasked = zeros([H,W,noOfLevels],'uint8');
figure
p1 = -1; p2 = 0;
for ii = 1:noOfLevels
    mask(:,:,ii) = quantImg == ii;
    imgMasked(:,:,ii) = img.*uint8(mask(:,:,ii));
    level = ['Level ' num2str(ii) '/' num2str(noOfLevels)];
    p1 = p1 + 2; p2 = p2 + 2;
    subplot(noOfLevels,2,p1)
    imshow(mask(:,:,ii));
    title([level ' - mask'])
    subplot(noOfLevels,2,p2)
    imshow(imgMasked(:,:,ii));
    title([level ' - masked image'])
end