function M = M_cont_modified3D(Pvid, d_p)

% Calculates the mixing index of a video using the modified contact
% method.

% Theodoros-Nestor Papapetrou
% Last edited: 27 Oct 2020

%% Input

% Pvid: uint8 H x W x F matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)
% P represents a video of the rotating drum with red and white particles

% d_p: the diameter of the balls in the rotating drum (in pixels),
% the same for both kinds of balls (scalar)

%% Output

% M: F x 1 double matrix, values between 0 and 1. Contains the values of
% the mixing index for each frame of the video.

%% Calculations

F = size(Pvid,3);
M = zeros(F,1);

for fr = 1:F
    P = Pvid(:,:,fr);
    M(fr) = M_cont_modified(P,d_p);
end