function [Xbot, Ybot] = bottomSurface(P)

% Extracts the coordinates of the bottom surface of a rotating drum. The
% output coordinates are given as x and y coordinates (not image
% columns / rows).

% Theodoros-Nestor Papapetrou
% Last edited: 06 Nov 2020

%% Input

% P: uint8 H x W matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)
% P represents an image of the rotating drum with red and white particles

%% Output

% Xbot: array with the x-coordinates of the points of the bottom surface
% (in pixels)

% Ybot: array with the y-coordinates of the points of the bottom surface
% (in pixels)

%% Calculations

[H,W] = size(P);

col_indicator = ones(1,W); % indicator of non-empty columns
rows = zeros(1,W); % rows of the last non-zero element of each column

for jj = 1:W
    r = find(P(:,jj),1,'last'); % row of the last non-zero element of the
                                % jj-th column
    if isempty(r) % the column is empty
        col_indicator(jj) = 0;
    else % the column is not empty
        rows(jj) = r;
    end
end

cols = 1:W;
cols = cols(col_indicator == 1); % non-empty columns
Xbot = imcols2x(cols);

rows = rows(col_indicator == 1);
Ybot = imrows2y(rows,H);