% cameraProcessing3

% The color segmentation thresholds have to be determined for the reference
% frame, using the Color Thresholder app.

% Theodoros-Nestor Papapetrou
% Last edited: 24 Nov 2020

%% Segmentation into red - white - black

% Thresholds

accept = 0;
while ~accept
    thrR1 = input('Give the first red HSV threshold: ');
    thrR2 = input('Give the second red HSV threshold: ');
    thrR3 = input('Give the red RGB threshold: ');
    thrW1 = input('Give the first white HSV threshold: ');
    thrW2 = input('Give the second white HSV threshold: ');
    segmentationParameters.thresRedHSV = [thrR1,thrR2];
    segmentationParameters.thresRedRGB = thrR3;
    segmentationParameters.thresWhiteHSV = [thrW1,thrW2];
    disp(segmentationParameters);
    accept = logical(input('Check the thresholds you gave. Are they correct (1: yes, 0: no)? '));
end
clear accept

segmentationParameters.noOfMorphOps = 3;
segmentationParameters.strelWidth = 3;
calculations.segmentationParameters = segmentationParameters;

disp('Segmenting masked video into red - white - black...');
calculations.Pvid = RGBVid2P(vidMasked,segmentationParameters,20);
vidSegmented = Pvid2RGB(calculations.Pvid);
disp('Video segmented.');
frate = experimentalConditions.framerate_fps;
disp('Saving segmented video...');
writeVideo2Path(vidSegmented, 'results\segmented.avi', frate);
disp('Segmented video saved.');

%% Segmented reference frame

copyfile diameterMeasurements.xlsx results
rfN = calculations.referenceFrameNumber;
referenceFrameP = Pvid2RGB(calculations.Pvid(:,:,rfN));
disp('Saving the reference frame...');
imwrite(referenceFrameP, 'results\referenceFrameP.png');
disp('Reference frame saved.');

%% Average red concentration, drum circle and angle of repose

calculations.averageRedConcentration = find_c_avg(calculations.Pvid);
disp('Extracting drum circle and angle of repose...');
noOfFrames = size(calculations.Pvid,3);
for ii = 1:noOfFrames
    P = calculations.Pvid(:,:,ii);
    [a_repose, ~, ~, polyn, R2] = angleOfRepose(P);
    topSurfaceLinear.angleOfRepose_degrees(ii) = a_repose;
    topSurfaceLinear.polynomial(:,ii) = polyn;
    topSurfaceLinear.R2(ii) = R2;
    [f, ~, drumCircle, h] = fillingDegree1(P);
    calculations.drumCircle(ii,:) = drumCircle;
    topSurfaceLinear.fillingDegree(ii) = f;
    topSurfaceLinear.fillingHeight(ii) = h;
    calculations.topSurfaceLinear = topSurfaceLinear;
end
disp('Drum circle and angle of repose extracted.');

%% Videos with features

parf.features.image = 1;
parf.features.straightLine = 1;
parf.features.drumCircle = 1;
parf.track = 20;
disp('Creating masked video with features...');
vidMaskedFeatures = drumVideoWithFeatures(calculations,parf,vidMasked);
disp('Masked video with features created.');
disp('Creating segmented video with features...');
vidSegmentedFeatures = drumVideoWithFeatures(calculations,parf);
disp('Segmented video with features created.');
disp('Saving videos with features...');
writeVideo2Path(vidMaskedFeatures, 'results\masked_features.avi', frate);
writeVideo2Path(vidSegmentedFeatures, 'results\segmented_features.avi', frate);
disp('Videos with features saved.');

clear thrR1 thrR2 thrR3 thrW1 thrW2 
clear segmentationParameters ii maskedRGBImage
clear P drumCircle f polyn h a_repose R2 topSurfaceLinear parf frate

save('results\data.mat');