function [BW,maskedRGBImage,thres] = createMaskWhiteHSV(RGB,thres)
%createMask  Threshold RGB image using auto-generated code from colorThresholder app.
%  [BW,MASKEDRGBIMAGE] = createMask(RGB) thresholds image RGB using
%  auto-generated code from the colorThresholder app. The colorspace and
%  range for each channel of the colorspace were set within the app. The
%  segmentation mask is returned in BW, and a composite of the mask and
%  original RGB images is returned in maskedRGBImage.

% Auto-generated by colorThresholder app on 23-Apr-2020
%------------------------------------------------------

% The white part is segmented from an image of the rotating drum.

% Theodoros-Nestor Papapetrou
% Last edited: 07 Oct 2020

%% Input

% RGB: H x W x 3 uint8 matrix, the RGB image to be segmented. This is
% expected to be an experimental image. The white part of RGB is segmented
% using thresholds in the S and V channels of HSV.

% thres: vector with 2 scalars between 0 and 1.
    % thres(1) is the maximum threshold for the S channel.
    % thres(2) is the minimum threshold for the V channel.
% If thres is not given, the default values, determined for the
% experimental video, are used.

%% Output

% BW: H x W x 3 logical matrix, the segmentation mask.

% maskedRGBImage: H x W x 3 uint8 matrix, a composite of BW and RGB.

% thres: the used thresholds

%% Apply default thresholds if necessary
if nargin < 2
    thres(1) = 0.438;
    thres(2) = 0.232;
end

%% Thresholding
% Convert RGB image to chosen color space
I = rgb2hsv(RGB);

% Define thresholds for channel 1 based on histogram settings
channel1Min = 0.000;
channel1Max = 1.000;

% Define thresholds for channel 2 based on histogram settings
channel2Min = 0.000;
channel2Max = thres(1);

% Define thresholds for channel 3 based on histogram settings
channel3Min = thres(2);
channel3Max = 1.000;

% Create mask based on chosen histogram thresholds
sliderBW = ( (I(:,:,1) >= channel1Min) | (I(:,:,1) <= channel1Max) ) & ...
    (I(:,:,2) >= channel2Min ) & (I(:,:,2) <= channel2Max) & ...
    (I(:,:,3) >= channel3Min ) & (I(:,:,3) <= channel3Max);
BW = sliderBW;

% Initialize output masked image based on input image.
maskedRGBImage = RGB;

% Set background pixels where BW is false to zero.
maskedRGBImage(repmat(~BW,[1 1 3])) = 0;

end
