function drum_circle = drumCircle(P)

% Estimates the position of the center of the drum and its radius (in
% pixels) in the image (P), using the lowest color pixel from each
% column and fitting a least-square circle. The image should not have any
% noise below the free surface of the circles.
% The following code is used for the fitting:

% Nikolai Chernov (2020). Circle Fit (Pratt method)
% (https://www.mathworks.com/matlabcentral/fileexchange/22643-circle-fit-pratt-method),
% MATLAB Central File Exchange. Retrieved August 15, 2019.

% Theodoros-Nestor Papapetrou
% Last edited: 06 Nov 2020

%% Input

% P: uint8 H x W matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)
% P represents an image of the rotating drum with red and white particles

%% Output

% drum_circle = [x y r]: the parameters of the circle approximation of the
% drum (x, y: coordinates of the center, r: radius; scalars, all in pixels)

%% Extract the coordinates of the bottom surface
[X, Y] = bottomSurface(P);

%% Find the circle

XY = [X; Y]';
drum_circle = CircleFitByPratt(XY);