function fig = drumImageWithFeatures(calc,frame,features,RGB)

% Displays the image RGB together with the specified features, calculated
% from the data in calc for the specified frame. If an image is not given,
% the corresponding frame from the Pvid in calc is displayed instead.

% Theodoros-Nestor Papapetrou
% Last edited: 22 Nov 2020

%% Input

% calc: structure

% frame: integer, the frame number used to obtain data from calc

% features: structure, the selected features to be displayed

% RGB: H x W x 3 uint8 matrix, the RGB image of the rotating drum

%% Output

% fig: figure handle

%% Display image

fig = figure;
hold on
H = size(calc.Pvid(:,:,frame),1);

if features.image
    if nargin < 4
        RGB = Pvid2RGB(calc.Pvid(:,:,frame));
    end
    imshow(RGB);
    hold on
end

%% Display straight line

if features.straightLine
    polyn = calc.topSurfaceLinear.polynomial(:,frame);
    drum = calc.drumCircle(frame,:);
    
    % Find crossing points of line and drum
    coef(1) = 1 + polyn(1)^2;
    coef(2) = 2*(polyn(1)*(polyn(2) - drum(2)) - drum(1));
    coef(3) = drum(1)^2 + (polyn(2) - drum(2))^2 - drum(3)^2;
    cros = roots(coef);
    x_left = min(cros);
    x_right = max(cros);
    xl = [x_left, x_right];
    yl = polyval(polyn,xl);
    
    % Plot line
    if features.image
        lrows = y2imrows(yl,H);
        lcols = x2imcols(xl);
        plot(lcols,lrows);
    else
        plot(xl,yl);
    end
    hold on
end

%% Display drum circle

if features.drumCircle
    drum = calc.drumCircle(frame,:);
    theta = linspace(0,2*pi,2000);
    xdr = drum(1) + drum(3)*cos(theta);
    ydr = drum(2) + drum(3)*sin(theta);
    
    if features.image
        drcols = x2imcols(xdr);
        drrows = y2imrows(ydr,H);
        plot(drcols,drrows);
    else
        plot(xdr,ydr);
    end
end
