function vid = drumVideoWithFeatures(calc,params,RGBVid)

% Creates a video containing the frames of RGBVid together with the
% specified features, calculated from the data in calc. If a video is not
% given, the frames of Pvid in calc are displayed instead.

% Theodoros-Nestor Papapetrou
% Last edited: 22 Nov 2020

%% Input

% calc: structure

% params: structure, contains the selected features to be displayed and
% the tracking period

% RGBVid: H x W x 3 x F uint8 matrix, the RGB video of the rotating drum

%% Output

% vid: H x W x 3 x F uint8 matrix, the RGB video with the features

% fig = drumImageWithFeatures(calc,frame,features,RGB)

%% Initialization

track = max([floor(params.track(1)) 0]);
features = params.features;
RGBVid_given = nargin >= 3;
Frames = size(calc.Pvid,3);
if track > 0
    strF = num2str(Frames);
end

%% Frame 1

if mod(1, track) == 0
    strfr = num2str(1);
    msg = ['Current frame: ',strfr,'/',strF];
    disp(msg);
end
if RGBVid_given
    RGB = RGBVid(:,:,:,1);
    drumImageWithFeatures(calc,1,features,RGB);
else
    drumImageWithFeatures(calc,1,features);
end
F = getframe;
close
RGBnew = frame2im(F);
[H,W,Ch] = size(RGBnew);
vid = zeros(H,W,Ch,Frames,'uint8');
vid(:,:,:,1) = RGBnew;

%% Frames 2 to last

if Frames > 1
    for fr = 2:Frames
        if mod(fr, track) == 0
            strfr = num2str(fr);
            msg = ['Current frame: ',strfr,'/',strF];
            disp(msg);
        end
        if RGBVid_given
            RGB = RGBVid(:,:,:,fr);
            drumImageWithFeatures(calc,fr,features,RGB);
        else
            drumImageWithFeatures(calc,fr,features);
        end
        F = getframe;
        close
        RGBnew = frame2im(F);
        vid(:,:,:,fr) = RGBnew;
    end
end
