function x = imcols2x(cols)

% Converts the column numbers of an image to x coordinates.
% The x and y axes have the usual orientation and the origin is at the low
% left corner of the image. The resulting x and y are at the center of the
% corresponding pixels.
% For example, the pixel at the left bottom of the matrix with column
% number 1 and row number H (the height of the matrix), has coordinates
% x=0.5, y=0.5
% This is the inverse function of x2imcols.

% Theodoros-Nestor Papapetrou
% Last edited: 05 Oct 2020

%% Input

% cols: array containing column numbers of an image matrix

%% Output

% x: array (same size as cols) with the corresponding x-coordinates of the
% columns, with respect to the xy-system

%% Calculation

if ~isempty(cols)
    x = cols - 0.5;
else
    error('Empty input')
end