function videoMasked = maskVideoWithCircle(video,Par_rowcol,inside)

% Masks all the frames of a video using a circular mask, whose parameters
% are given in Par_rowcol.

% Theodoros-Nestor Papapetrou
% 05.03.2020

%% Input

% video: HxW(x3)xF uint8 matrix, the video to be masked.

% Par_rowcol: double array with 3 elements, containing the mask parameters:
%   Par_rowcol(1): column of the center of the circle mask
%   Par_rowcol(2): row of the center of the circle mask
%   Par_rowcol(3): radius of the circle mask (pixels)

% inside: logical scalar, indicates which part of the original video is
% visible after the masking:
%   inside = 1 (default): everything outside the circle is turned to black
%   inside = 0: everything inside the circle is turned to black

%% Output

% videoMasked: uint8 matrix of the same size as video, the original video
% masked.

%% Mask creation

if nargin < 3
    inside = 1;
end

inside = logical(inside);

H = size(video,1);
W = size(video,2);

col = Par_rowcol(1);
row = Par_rowcol(2);
r = Par_rowcol(3);

mask = circle([H W],[row col],r);
if ~inside
    mask = 1 - mask;
end

%% Apply mask to video

videoMasked = video.*mask;
