function [P_short, topleft, original_size] = remove_0_cols_rows(P)

% Removes the columns and rows of P consisting entirely of zero
% (background) values which surround the main part of P. Any zero columns
% or rows passing through the main part are not removed.

% Theodoros-Nestor Papapetrou
% Last edited: 05 Nov 2020

%% Input

% P: uint8 H x W matrix with values corresponding to colors:
% 1: red, 2: white, 0: background (black)
% P represents an image of the rotating drum with red and white particles

%% Output

% P_short: P without the surrounding black rows and columns

% topleft: 1 x 2 uint8 matrix, contains the number of the first non-zero
% row and the first non-zero column in the original P

% topleft: 1 x 2 uint8 matrix, the coordinates of the top left pixel of the
% main part of P in the order:
%   first nonzero row
%   first nonzero column

% original_size: 1 x 2 uint8 matrix, the size of the original P

%% Calculation

firstcol = find(any(P),1); % first nonzero column
firstrow = find(any(P,2),1); % first nonzero row
lastcol = find(any(P),1,'last'); %last nonzero column
lastrow = find(any(P,2),1,'last'); %last nonzero row
topleft = [firstrow, firstcol];
original_size = size(P);
P_short = P(firstrow:lastrow,firstcol:lastcol);

% P_short=P(any(P,2),any(P,1));