function cols = x2imcols(x)

% Converts the x coordinates of an image to column numbers.
% The x and y axes have the usual orientation and the origin is at the low
% left corner of the image. The resulting x and y are at the center of the
% corresponding pixels.
% For example, the pixel at the left bottom of the matrix with column
% number 1 and row number H (the height of the matrix), has coordinates
% x=0.5, y=0.5
% This is the inverse function of imcols2x.

% Theodoros-Nestor Papapetrou
% Last edited: 05 Oct 2020

%% Input

% x: array containing the x-coordinates of some points of an image, with
% respect to the xy-system.

%% Output

% cols: array (same size as x) with the corresponding column numbers of the
% points in x

%% Calculation

if ~isempty(x)
    cols = x + 0.5;
else
    error('Empty input')
end