function rows = y2imrows(y,height)

% Converts the y coordinates of an image to row numbers.
% The x and y axes have the usual orientation and the origin is at the low
% left corner of the image. The resulting x and y are at the center of the
% corresponding pixels.
% For example, the pixel at the left bottom of the matrix with column
% number 1 and row number H (the height of the matrix), has coordinates
% x=0.5, y=0.5
% This is the inverse function of imrows2y.

% Theodoros-Nestor Papapetrou
% Last edited: 05 Oct 2020

%% Input

% y: array containing the y-coordinates of some points of an image, with
% respect to the xy-system.

% height: the number of rows of the image (integer scalar)

%% Output

% rows: array (same size as y) with the corresponding row numbers of the
% points in y

%% Calculation

if ~isempty(y)
    rows = height + 0.5 - y;
else
    error('Empty input')
end